import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import { resolve } from 'path'; // 主要用于alias文件路径别名

function pathResolve(dir: string) {
  return resolve(__dirname, '.', dir);
}

export default defineConfig({
  plugins: [vue()], // 配置需要使用的插件列表
  
  resolve: {
    alias: {
      "/@/": pathResolve("src")+'/', // 这里是将src目录配置别名为 /@ 方便在项目中导入src目录下的文件
    }
  },
  
  server: { //主要是加上这段代码
    host: '127.0.0.1',
    port: 3000,
    proxy: {
      '/api': {
        target: process.env.VITE_API_BASE_URL, //实际请求地址
        changeOrigin: true,
        ws: true,
        rewrite: (path) => path.replace(/^\/api/, '')
      },
    }
  },
  
  css: {
    // css预处理器
    preprocessorOptions: {
      less: {
        lessOptions: {
          javascriptEnabled: true
        }
      },
    },
  }
})